==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>གཞི་རྩའི་ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ཆ་འཕྲིན་ཞིབ་ཕྲ།</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>པར་དེབ་ཏུ་སྣོན་པ། </translation>
    </message>
    <message>
        <source>New album</source>
        <translation>པར་དེབ་གསར་བཟོ།</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>པར་ཚང་མ།</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>པར་ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ཕྱིར་འདྲེན།</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>པར་དེབ་ནས་སྤོ་འབུད་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་འདོར་བ།</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>པར་ལྟ་བའི་དབང་ཚད་མེད།</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>པར་གྱི་རིགས་ཁག</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>བཅོས་པའི་དུས་ཚོད།</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>ཡིག་ཆའི་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>པར་ལེན་དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>འོད་ཐོག་རྣམ་པ། </translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>འོད་ཕོག་བྱ་རིམ། </translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>འོད་ཕོག་དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>འཁྱུག་སྒྲོན། </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>འོད་ཁུང་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>མདོ་ཐག</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISOའོད་ལེན་ཚད།</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>འོད་ཁུང་ཆེ་ཤོས།</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>འོད་འཇལ་རྣམ་པ། </translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>དཀར་སྙོམས། </translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>འཁྱུག་སྒྲོན་ཁ་གསབ།</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>ཤེལ་མགོའི་བཟོ་རྟགས། </translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>ཚོས་གཞིའི་བར་སྟོང་།</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>པར་ཆས་བཟོ་རྟགས། </translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>པར་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>རྟགས། </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>ཕྱིར་ལོག</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>སྔ་མ།</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ཕྱི་མ།</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>སྒེའུ་ཁུང་དང་འཚམ་པ།</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ཕྱི་སྐོར་ལྟར་སྐོར་བ།</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ནང་སྐོར་ལྟར་སྐོར་བ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ། </translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>ཡོལ་གང་ལས་ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ཡོལ་གང་།</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས།</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>སྒྲོན་བཪྙན་པར་ཤེལ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཟོ།</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>མིང་བསྐྱར་འདོགས།</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་མངོན་པ།</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>རྩིག་ཤོག་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ཡིག་ཆ་དོ་དམ་ཆས་ནང་དུ་མངོན་པ།</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>day</source>
        <translation>ཉིན།</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>གཏན་འཁེལ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>པར་གྱི་མིང་འཇུག་རོགས།</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>སྔ་མ།</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>སྐབས་སྡོད།</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>གཏོང་བ།</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ཕྱི་མ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>པར་གྱི་ཡིག་ཆ་ཪྙེད་མ་བྱུང་།`</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>པར་གྱི་ཡིག་ཆ་ཪྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>ཡིག་ཆ་ལྟ་བའི་དབང་ཚད་མེད།</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.39.orig.tar.xz: image-editor-1.0.39/libimageviewer/translations/libimageviewer_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>གཞི་རྩའི་ཆ་འཕྲིན། </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ཆ་འཕྲིན་ཞིབ་ཕྲ།</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>པར་དེབ་ཏུ་སྣོན་པ། </translation>
    </message>
    <message>
        <source>New album</source>
        <translation>པར་དེབ་གསར་བཟོ།</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>པར་ཚང་མ།</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>པར་ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ཕྱིར་འདྲེན།</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>པར་དེབ་ནས་སྤོ་འབུད་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>ཉར་ཚགས་འདོར་བ།</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ཉར་ཚགས།</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>པར་ལྟ་བའི་དབང་ཚད་མེད།</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>པར་གྱི་རིགས་ཁག</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>བཅོས་པའི་དུས་ཚོད།</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>ཡིག་ཆའི་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>པར་ལེན་དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>འོད་ཐོག་རྣམ་པ། </translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>འོད་ཕོག་བྱ་རིམ། </translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>འོད་ཕོག་དུས་ཚོད། </translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>འཁྱུག་སྒྲོན། </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>འོད་ཁུང་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>མདོ་ཐག</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISOའོད་ལེན་ཚད།</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>འོད་ཁུང་ཆེ་ཤོས།</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>འོད་འཇལ་རྣམ་པ། </translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>དཀར་སྙོམས། </translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>འཁྱུག་སྒྲོན་ཁ་གསབ།</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>ཤེལ་མགོའི་བཟོ་རྟགས། </translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>ཚོས་གཞིའི་བར་སྟོང་།</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>པར་ཆས་བཟོ་རྟགས། </translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>པར་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>རྟགས། </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>ཕྱིར་ལོག</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>སྔ་མ།</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ཕྱི་མ།</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>སྒེའུ་ཁུང་དང་འཚམ་པ།</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>ཡི་གེ་ངོས་འཛིན།</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ཕྱི་སྐོར་ལྟར་སྐོར་བ།</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ནང་སྐོར་ལྟར་སྐོར་བ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ། </translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>ཡོལ་གང་ལས་ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ཡོལ་གང་།</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས།</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>སྒྲོན་བཪྙན་པར་ཤེལ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཟོ།</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>མིང་བསྐྱར་འདོགས།</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་མངོན་པ།</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>ཕྱོགས་སྟོན་སྒེའུ་ཁུང་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>རྩིག་ཤོག་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ཡིག་ཆ་དོ་དམ་ཆས་ནང་དུ་མངོན་པ།</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>པར་གྱི་ཆ་འཕྲིན།</translation>
    </message>
    <message>
        <source>day</source>
        <translation>ཉིན།</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>གཏན་འཁེལ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>པར་གྱི་མིང་འཇུག་རོགས།</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>སྔ་མ།</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>སྐབས་སྡོད།</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>གཏོང་བ།</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ཕྱི་མ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>པར་གྱི་ཡིག་ཆ་ཪྙེད་མ་བྱུང་།`</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>པར་གྱི་ཡིག་ཆ་ཪྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>ཡིག་ཆ་ལྟ་བའི་དབང་ཚད་མེད།</translation>
    </message>
</context>
</TS>
